# TestCaseExportField


## Enum

* `ALLURE_ID` (value: `'allure_id'`)

* `NAME` (value: `'name'`)

* `FULL_NAME` (value: `'full_name'`)

* `AUTOMATED` (value: `'automated'`)

* `DESCRIPTION` (value: `'description'`)

* `PRECONDITION` (value: `'precondition'`)

* `EXPECTED_RESULT` (value: `'expected_result'`)

* `STATUS` (value: `'status'`)

* `SCENARIO` (value: `'scenario'`)

* `ISSUE_INTEGRATION` (value: `'issue_integration'`)

* `TAG` (value: `'tag'`)

* `LINK` (value: `'link'`)

* `CUSTOM_FIELD` (value: `'custom_field'`)

* `ROLE` (value: `'role'`)

* `EXAMPLE` (value: `'example'`)

* `PARAMETER` (value: `'parameter'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


